//
//  ContentView.swift
//  IdGraphLocationSample
//
//  Created by Charles Wang on 2024/10/17.
//

import SwiftUI
import TAMIdGraph

struct ContentView: View {    
    @StateObject var locationManager = LocationManager()

    var body: some View {
        VStack {
            Image(systemName: "location.viewfinder")
                .imageScale(.large)
                .foregroundStyle(.tint)
            Text("Location:")
            if let location = locationManager.location {
                Text("Latitude: \(location.coordinate.latitude)")
                Text("Longitude: \(location.coordinate.longitude)")
            } else {
                Text("Fetching location...")
            }

            Button {
                locationManager.startUpdatingLocation()
            } label: {
                Text("Get location")
                    .padding()
                    .background(.blue)
                    .foregroundColor(.white)
                    .cornerRadius(15)
            }
            
            Button {
                if let location = locationManager.location {
                    ///回報 TAmedia IDGraph
                    ///帶入 Service ID, customParameters 第一位帶入經度第二位帶入緯度
                    TAMIdGraphManager.initWithServiceId("38x2V96diwCS", customParameters: ["\(location.coordinate.longitude)", "\(location.coordinate.latitude)"])
                }
            } label: {
                Text("Report location")
                    .padding()
                    .background(.blue)
                    .foregroundColor(.white)
                    .cornerRadius(15)
            }
        }
        .padding()
    }
}

#Preview {
    ContentView()
}


